@@ -34,7 +34,7 @@ def activate_venv(path):
     if OS == "Windows":
         env_activate_script = "Scripts"
 
-    activate_file = os.path.join(path, "env", env_activate_script, "activate")
+    activate_file = os.path.join(path, "venv", env_activate_script, "activate")
     print("🔧🔧 downloading packages")
     os.system(f"{activate_file} && pip install -r requirements.txt")
 
@@ -49,6 +49,6 @@ def start(template_name):
     folder_name = pathlib.PurePath(path)
     
     if OS == "Windows":
-        activate_file = os.path.join("env", "Scripts", "activate")
+        activate_file = os.path.join("venv", "Scripts", "activate")
         print(f"cd {folder_name.name}; {activate_file}")
 
